@@ -973,8 +973,8 @@ def pbdDict_bxReposRoot(
         vcMode
     )
     gitClone(
-        'blee/envsShar',
-        'bx-blee/envsShar',
+        'blee/envsShare',
+        'bx-blee/envsShare',
         vcMode
     )
     gitClone(
@@ -1095,7 +1095,12 @@ def pbdDict_bxReposRoot(
         'bx-blee/persian-input-method',
         vcMode
     )
-
+    gitClone(
+        'blee/fshell',
+        'bx-blee/fshell',
+        vcMode
+    )
+    
     gitCloneBase('bxGenesis', 'bxGenesis/base', vcMode)
     gitClone('bxGenesis/overview', 'bxGenesis/overview', vcMode)
     gitClone('bxGenesis/vagrants', 'bxGenesis/vagrants', vcMode)
